==> %E6%A0%A1%E5%BF%AB%E9%80%812024.11.19v0.0.4.tar.gz: xiaokuaisong-houduan/school_lend_back_end/src/main/java/com/bsz/school_send_back_end/controller/BusinessController.java <==
package com.bsz.school_send_back_end.controller;


import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.bsz.school_send_back_end.annotation.AuthCheck;
import com.bsz.school_send_back_end.common.BaseResponse;
import com.bsz.school_send_back_end.common.ErrorCode;
import com.bsz.school_send_back_end.common.ResultUtils;
import com.bsz.school_send_back_end.contant.UserConstant;
import com.bsz.school_send_back_end.exception.BusinessException;
import com.bsz.school_send_back_end.exception.ThrowUtils;
import com.bsz.school_send_back_end.model.domain.Business;
import com.bsz.school_send_back_end.model.domain.BusinessAuth;
import com.bsz.school_send_back_end.model.domain.User;
import com.bsz.school_send_back_end.model.dto.business.BusinessAddRequest;
import com.bsz.school_send_back_end.model.dto.business.BusinessQueryRequest;
import com.bsz.school_send_back_end.model.dto.business.BusinessUpdateMyRequest;
import com.bsz.school_send_back_end.model.dto.business.BusinessUpdateRequest;
import com.bsz.school_send_back_end.model.vo.BusinessAdminVO;
import com.bsz.school_send_back_end.model.vo.BusinessVO;
import com.bsz.school_send_back_end.service.BusinessAuthService;
import com.bsz.school_send_back_end.service.BusinessService;
import com.bsz.school_send_back_end.service.UserService;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.util.DigestUtils;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;

import java.util.List;

import static com.bsz.school_send_back_end.contant.UserConstant.USER_SALT;

/**
 * 商家接口
 */
@Slf4j
@RestController
@RequestMapping("/business")
public class BusinessController {

    @Resource
    private BusinessService businessService;

    @Resource
    private BusinessAuthService businessAuthService;

    @Resource
    private UserService userService;

    @PostMapping("/add")
    public BaseResponse<Long> addBusiness(@RequestBody BusinessAddRequest businessAddRequest) {

        ThrowUtils.throwIf(businessAddRequest == null,ErrorCode.PARAMS_ERROR);

        User user = new User();
        BeanUtils.copyProperties(businessAddRequest, user);
        Business business = new Business();
        BeanUtils.copyProperties(businessAddRequest, business);
        BusinessAuth businessAuth = new BusinessAuth();
        BeanUtils.copyProperties(businessAddRequest, businessAuth);

        //对每个应该校验的业务进行校验
        businessService.validUser(user, true);
        businessService.validBusiness(business, true);
        businessService.validBusinessAuth(businessAuth, true);

        //加密
        String encryptPassword = DigestUtils.md5DigestAsHex((USER_SALT + user.getUserPassword()).getBytes());
        user.setUserPassword(encryptPassword);

        //更改用户权限为商家
        user.setUserRole("business");

        //往user表中补充商家信息
        user.setUsername(business.getBusinessName());
        user.setAvatarUrl(business.getBusinessAvatar());
        user.setPhone(business.getBusinessPhone());

        //插入到表中
        businessService.addBusiness(user, business, businessAuth);

        return ResultUtils.success(business.getId(),"添加商家成功");

    }

    /**
     * 管理员更新商家
     */
    @PostMapping("/update")
    @AuthCheck(mustRole = UserConstant.ADMIN_ROLE)
    public BaseResponse<Boolean> updateBusiness (@RequestBody BusinessUpdateRequest businessUpdateRequest) {
        if (businessUpdateRequest == null || businessUpdateRequest.getId() == null) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR, "传入参数为空");
        }

        Business business = new Business();

        BeanUtils.copyProperties(businessUpdateRequest, business);
        //更新不添加 只需要判断修改符不符合逻辑
        businessService.validBusiness(business, false);

        boolean updateById = businessService.updateById(business);

        ThrowUtils.throwIf(!updateById, ErrorCode.OPERATION_ERROR);

        return ResultUtils.success(true);
    }

    /**
     * 商家更新个人信息
     */
    @PostMapping("/update/my")
    @AuthCheck(mustRole = UserConstant.BUSINESS_ROLE)
    public BaseResponse<Boolean> updateMyBusiness (@RequestBody BusinessUpdateMyRequest businessUpdateMyRequest, HttpServletRequest request) {

        if (businessUpdateMyRequest == null) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR);
        }

        // 获取当前登录商家信息
        Business loginBusiness = businessService.getLoginBusiness(request);
        ThrowUtils.throwIf(loginBusiness == null, ErrorCode.NOT_FOUND_ERROR);
        Business business = new Business();
        business.setId(loginBusiness.getId());
        business.setUserId(loginBusiness.getUserId());
        BeanUtils.copyProperties(businessUpdateMyRequest, business);
        // 校验
        businessService.validBusiness(business, false);
        // 修改商家信息
        boolean updateBusiness = businessService.updateById(business);
        ThrowUtils.throwIf(!updateBusiness, ErrorCode.OPERATION_ERROR, "修改商家信息失败");
        // 修改用户信息
        User loginUser = userService.getById(loginBusiness.getUserId());
        if (StringUtils.isNotBlank(business.getBusinessName())) {
            loginUser.setUsername(business.getBusinessName());
        }
        if (StringUtils.isNotBlank(business.getBusinessPhone())) {
            loginUser.setPhone(business.getBusinessPhone());
        }
        boolean updateUser = userService.updateById(loginUser);
        ThrowUtils.throwIf(!updateUser, ErrorCode.OPERATION_ERROR, "修改用户信息失败");
        return ResultUtils.success(true);
    }

    /**
     * 根据id查询
     */
    @GetMapping("/getById")
    @AuthCheck(mustRole = UserConstant.ADMIN_ROLE)
    public BaseResponse<BusinessAdminVO> getBusinessById(@RequestParam Long id) {
        if (id <= 0) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR);
        }

        Business business = businessService.getById(id);

        ThrowUtils.throwIf(business == null , ErrorCode.NULL_ERROR);

        BusinessAdminVO businessAdminVO = businessAuthService.getBusinessAdminVO(business);

        return ResultUtils.success(businessAdminVO);
    }

    /**
     * 根据当前登录用户获取商家信息
     */
    @PostMapping("/get/current")
    public BaseResponse<BusinessVO> getByBusiness (HttpServletRequest request) {
        Business loginBusiness = businessService.getLoginBusiness(request);
        BusinessVO businessVO = businessService.getBusinessVO(loginBusiness);
        return ResultUtils.success(businessVO);
    }
    /**
     * 查询所有商家
     */
    @PostMapping("/list")
    public BaseResponse<List<Business>> listBusinessAll(){
        List<Business> businessList = businessService.list();
        return new BaseResponse<>(0,businessList,"查询成功");
    }


    /**
     * 分页查询
     */
    @PostMapping("/list/page")
    @AuthCheck(mustRole = UserConstant.ADMIN_ROLE)
    public BaseResponse<Page<Business>> listBusinessByPage (@RequestBody BusinessQueryRequest businessQueryRequest) {
        Page<Business> businessPage = businessService.page(new Page<>(businessQueryRequest.getCurrent(), businessQueryRequest.getPageSize()),
                businessService.getQueryWrapper(businessQueryRequest));
        return ResultUtils.success(businessPage);

    }

    /**
     * 分页获取商家列表（用户视图）
     */
    @PostMapping("/list/page/vo")
    public BaseResponse<Page<BusinessVO>> listBusinessVOByPage(@RequestBody BusinessQueryRequest businessQueryRequest) {
        long current = businessQueryRequest.getCurrent();
        long size = businessQueryRequest.getPageSize();

        ThrowUtils.throwIf(size > 20, ErrorCode.PARAMS_ERROR);
        QueryWrapper<Business> queryWrapper = businessService.getQueryWrapper(businessQueryRequest);
        // 只显示正常营业商家
        queryWrapper.eq("state", 1);
        Page<Business> businessPage = businessService.page(new Page<>(current, size), queryWrapper);
        Page<BusinessVO> businessVOPage = new Page<>(current, size, businessPage.getTotal());
        List<BusinessVO> businessVOList = businessService.getBusinessVO(businessPage.getRecords());
        businessVOPage.setRecords(businessVOList);
        return ResultUtils.success(businessVOPage);
    }

    

}

==> %E6%A0%A1%E5%BF%AB%E9%80%812024.12.5v0.0.5.tar.gz: xiaokuaisong-houduan/school_lend_back_end/src/main/java/com/bsz/school_send_back_end/controller/BusinessController.java <==
package com.bsz.school_send_back_end.controller;


import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.bsz.school_send_back_end.annotation.AuthCheck;
import com.bsz.school_send_back_end.common.BaseResponse;
import com.bsz.school_send_back_end.common.ErrorCode;
import com.bsz.school_send_back_end.common.ResultUtils;
import com.bsz.school_send_back_end.contant.UserConstant;
import com.bsz.school_send_back_end.exception.BusinessException;
import com.bsz.school_send_back_end.exception.ThrowUtils;
import com.bsz.school_send_back_end.model.domain.Business;
import com.bsz.school_send_back_end.model.domain.BusinessAuth;
import com.bsz.school_send_back_end.model.domain.BusinessLevel;
import com.bsz.school_send_back_end.model.domain.User;
import com.bsz.school_send_back_end.model.dto.business.BusinessAddRequest;
import com.bsz.school_send_back_end.model.dto.business.BusinessQueryRequest;
import com.bsz.school_send_back_end.model.dto.business.BusinessUpdateMyRequest;
import com.bsz.school_send_back_end.model.dto.business.BusinessUpdateRequest;
import com.bsz.school_send_back_end.model.vo.BusinessAdminVO;
import com.bsz.school_send_back_end.model.vo.BusinessVO;
import com.bsz.school_send_back_end.service.BusinessAuthService;
import com.bsz.school_send_back_end.service.BusinessLevelService;
import com.bsz.school_send_back_end.service.BusinessService;
import com.bsz.school_send_back_end.service.UserService;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.util.DigestUtils;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;

import java.util.ArrayList;
import java.util.List;

import static com.bsz.school_send_back_end.contant.UserConstant.USER_SALT;

/**
 * 商家接口
 */
@Slf4j
@RestController
@RequestMapping("/business")
public class BusinessController {

    @Resource
    private BusinessService businessService;

    @Resource
    private BusinessAuthService businessAuthService;

    @Resource
    private UserService userService;

    @Resource
    private BusinessLevelService businessLevelService;

    @PostMapping("/add")
    public BaseResponse<Long> addBusiness(@RequestBody BusinessAddRequest businessAddRequest) {

        ThrowUtils.throwIf(businessAddRequest == null,ErrorCode.PARAMS_ERROR);

        User user = new User();
        BeanUtils.copyProperties(businessAddRequest, user);
        Business business = new Business();
        BeanUtils.copyProperties(businessAddRequest, business);
        BusinessAuth businessAuth = new BusinessAuth();
        BeanUtils.copyProperties(businessAddRequest, businessAuth);

        //对每个应该校验的业务进行校验
        businessService.validUser(user, true);
        businessService.validBusiness(business, true);
        businessService.validBusinessAuth(businessAuth, true);

        //加密
        String encryptPassword = DigestUtils.md5DigestAsHex((USER_SALT + user.getUserPassword()).getBytes());
        user.setUserPassword(encryptPassword);

        //更改用户权限为商家
        user.setUserRole("business");

        //往user表中补充商家信息
        user.setUsername(business.getBusinessName());
        user.setAvatarUrl(business.getBusinessAvatar());
        user.setPhone(business.getBusinessPhone());

        //插入到表中
        businessService.addBusiness(user, business, businessAuth);

        return ResultUtils.success(business.getId(),"添加商家成功");

    }

    /**
     * 管理员更新商家
     */
    @PostMapping("/update")
    @AuthCheck(mustRole = UserConstant.ADMIN_ROLE)
    public BaseResponse<Boolean> updateBusiness (@RequestBody BusinessUpdateRequest businessUpdateRequest) {
        if (businessUpdateRequest == null || businessUpdateRequest.getId() == null) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR, "传入参数为空");
        }

        Business business = new Business();

        BeanUtils.copyProperties(businessUpdateRequest, business);
        //更新不添加 只需要判断修改符不符合逻辑
        businessService.validBusiness(business, false);

        boolean updateById = businessService.updateById(business);

        ThrowUtils.throwIf(!updateById, ErrorCode.OPERATION_ERROR);

        return ResultUtils.success(true);
    }

    /**
     * 商家更新个人信息
     */
    @PostMapping("/update/my")
    @AuthCheck(mustRole = UserConstant.BUSINESS_ROLE)
    public BaseResponse<Boolean> updateMyBusiness (@RequestBody BusinessUpdateMyRequest businessUpdateMyRequest, HttpServletRequest request) {

        if (businessUpdateMyRequest == null) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR);
        }

        // 获取当前登录商家信息
        Business loginBusiness = businessService.getLoginBusiness(request);
        ThrowUtils.throwIf(loginBusiness == null, ErrorCode.NOT_FOUND_ERROR);
        Business business = new Business();
        business.setId(loginBusiness.getId());
        business.setUserId(loginBusiness.getUserId());
        BeanUtils.copyProperties(businessUpdateMyRequest, business);
        // 校验
        businessService.validBusiness(business, false);
        // 修改商家信息
        boolean updateBusiness = businessService.updateById(business);
        ThrowUtils.throwIf(!updateBusiness, ErrorCode.OPERATION_ERROR, "修改商家信息失败");
        // 修改用户信息
        User loginUser = userService.getById(loginBusiness.getUserId());
        if (StringUtils.isNotBlank(business.getBusinessName())) {
            loginUser.setUsername(business.getBusinessName());
        }
        if (StringUtils.isNotBlank(business.getBusinessPhone())) {
            loginUser.setPhone(business.getBusinessPhone());
        }
        boolean updateUser = userService.updateById(loginUser);
        ThrowUtils.throwIf(!updateUser, ErrorCode.OPERATION_ERROR, "修改用户信息失败");
        return ResultUtils.success(true);
    }

    /**
     * 根据id查询
     */
    @GetMapping("/getById")
    @AuthCheck(mustRole = UserConstant.ADMIN_ROLE)
    public BaseResponse<BusinessAdminVO> getBusinessById(@RequestParam Long id) {
        if (id <= 0) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR);
        }

        Business business = businessService.getById(id);

        ThrowUtils.throwIf(business == null , ErrorCode.NULL_ERROR);

        BusinessAdminVO businessAdminVO = businessAuthService.getBusinessAdminVO(business);

        return ResultUtils.success(businessAdminVO);
    }

    /**
     * 根据当前登录用户获取商家信息
     */
    @PostMapping("/get/current")
    public BaseResponse<BusinessVO> getByBusiness (HttpServletRequest request) {
        Business loginBusiness = businessService.getLoginBusiness(request);
        BusinessVO businessVO = businessService.getBusinessVO(loginBusiness);
        return ResultUtils.success(businessVO);
    }
    /**
     * 查询所有商家
     */
    @PostMapping("/list")
    public BaseResponse<List<BusinessVO>> listBusinessAll(){
        List<BusinessVO> business = businessService.findAllBusiness();
        return new BaseResponse<>(0,business,"查询成功");
    }


    /**
     * 分页查询
     */
    @PostMapping("/list/page")
    @AuthCheck(mustRole = UserConstant.ADMIN_ROLE)
    public BaseResponse<Page<Business>> listBusinessByPage (@RequestBody BusinessQueryRequest businessQueryRequest) {
        Page<Business> businessPage = businessService.page(new Page<>(businessQueryRequest.getCurrent(), businessQueryRequest.getPageSize()),
                businessService.getQueryWrapper(businessQueryRequest));
        return ResultUtils.success(businessPage);

    }

    /**
     * 分页获取商家列表（用户视图）
     */
    @PostMapping("/list/page/vo")
    public BaseResponse<Page<BusinessVO>> listBusinessVOByPage(@RequestBody BusinessQueryRequest businessQueryRequest) {
        long current = businessQueryRequest.getCurrent();
        long size = businessQueryRequest.getPageSize();

        ThrowUtils.throwIf(size > 20, ErrorCode.PARAMS_ERROR);
        QueryWrapper<Business> queryWrapper = businessService.getQueryWrapper(businessQueryRequest);
        // 只显示正常营业商家
        queryWrapper.eq("state", 1);
        Page<Business> businessPage = businessService.page(new Page<>(current, size), queryWrapper);
        Page<BusinessVO> businessVOPage = new Page<>(current, size, businessPage.getTotal());
        List<BusinessVO> businessVOList = businessService.getBusinessVO(businessPage.getRecords());
        businessVOPage.setRecords(businessVOList);
        return ResultUtils.success(businessVOPage);
    }

    

}
